@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright 2021-2023 Cardiff University
+# Copyright (c) 2021-2025 Cardiff University
 # Distributed under the terms of the BSD-3-Clause license
 
 """Python Requests interface with IGWN authentication.
@@ -13,6 +12,7 @@ __credits__ = "Leo Singer <leo.singer@ligo.org>"
 
 import sys
 from functools import wraps
+from textwrap import indent
 from unittest import mock
 
 import requests
@@ -31,15 +31,11 @@ from .x509 import (
     find_credentials as find_x509_credentials,
 )
 
-# handle https://github.com/psf/requests/issues/4025
-# NOTE: 2.14.1 is the base version on EPEL7
-REQUESTS_CERT_HTTP_BUG = '2.14.1' <= requests.__version__ < '2.15.0'
-
 
 # -- Auth utilities -------------------
 
 def _find_cred(func, *args, error=True, **kwargs):
-    """Find a credential and maybe ignore an `~igwn_auth_utils.IgwnAuthError`
+    """Find a credential and maybe ignore an `~igwn_auth_utils.IgwnAuthError`.
 
     This is an internal utility for the `SessionAuthMixin._init_auth`
     method which shouldn't necessary fail if it doesn't
@@ -56,16 +52,14 @@ def _find_cred(func, *args, error=True, **kwargs):
 
 @wraps(requests_utils.get_netrc_auth)
 def get_netrc_auth(url, raise_errors=False):
-    """Wrapper around `requests.utils.get_netrc_auth` to use `safe_netrc`.
-    """
     import safe_netrc
     with mock.patch.dict(sys.modules, {"netrc": safe_netrc}):
         return requests_utils.get_netrc_auth(url, raise_errors=raise_errors)
 
 
 class HTTPSciTokenAuth(_AuthBase):
-    """Auth handler for SciTokens.
-    """
+    """Auth handler for SciTokens."""
+
     def __init__(
         self,
         token=None,
@@ -79,6 +73,7 @@ class HTTPSciTokenAuth(_AuthBase):
         self.issuer = issuer
 
     def __eq__(self, other):
+        """Return `True` if this object provides the same auth as ``other``."""
         return all([
             self.token == getattr(other, "token", None),
             self.audience == getattr(other, "audience", None),
@@ -87,6 +82,7 @@ class HTTPSciTokenAuth(_AuthBase):
         ])
 
     def __ne__(self, other):
+        """Return `True` if this object and ``other`` provide the same auth."""
         return not self == other
 
     @staticmethod
@@ -129,8 +125,7 @@ class HTTPSciTokenAuth(_AuthBase):
         )
 
     def __call__(self, r):
-        """Augment the `Request` ``r`` with an ``Authorization`` header.
-        """
+        """Augment the `Request` ``r`` with an ``Authorization`` header."""
         token = self.token
         if token in (None, True):
             token = self.find_token(
@@ -157,16 +152,7 @@ def _prepare_auth(
     fail_if_noauth=False,
     session=None,
 ):
-    """Prepare authorisation for a session or request.
-    """
-    # workaround https://github.com/psf/requests/issues/4025
-    if (
-        cert is None
-        and str(url).startswith("http://")
-        and REQUESTS_CERT_HTTP_BUG
-    ):
-        cert = False
-
+    """Prepare authorisation for a session or request."""
     # merge settings from the session
     if session:
         if cert is None:
@@ -253,134 +239,137 @@ def _prepare_auth(
 # -- Session handling -----------------
 
 _auth_session_parameters = """
-    Discovery/configuration of authorisation/authentication methods
-    is attempted in the following order:
+Discovery/configuration of authorisation/authentication methods
+is attempted in the following order:
 
-    1.  if ``force_noauth=True`` is given, no auth is configured;
+1.  if ``force_noauth=True`` is given, no auth is configured;
 
-    2.  for SciTokens:
+2.  for SciTokens:
 
-        1.  if a bearer token is provided via the ``token`` keyword argument,
-            then use that, or
+    1.  if a bearer token is provided via the ``token`` keyword argument,
+        then use that, or
 
-        2.  look for a bearer token by passing the ``token_audience``
-            and ``token_scope`` keyword parameters to
-            :func:`igwn_auth_utils.find_scitokens`;
+    2.  look for a bearer token by passing the ``token_audience``
+        and ``token_scope`` keyword parameters to
+        :func:`igwn_auth_utils.find_scitokens`;
 
-    3.  for X.509 credentials:
+3.  for X.509 credentials:
 
-        1.  if an X.509 credential path is provided via the ``cert`` keyword
-            argument, then use that, or
+    1.  if an X.509 credential path is provided via the ``cert`` keyword
+        argument, then use that, or
 
-        2.  look for an X.509 credential using
-            :func:`igwn_auth_utils.find_x509_credential`
+    2.  look for an X.509 credential using
+        :func:`igwn_auth_utils.find_x509_credential`
 
-    4.  for basic auth (username/password):
+4.  for basic auth (username/password):
 
-        1.  if ``auth`` keyword is provided, then use that, or
+    1.  if ``auth`` keyword is provided, then use that, or
 
-        2.  read the netrc file located at :file:`~/.netrc`, or at the path
-            stored in the :envvar:`$NETRC` environment variable, and look
-            for a username and password matching the hostname given in the
-            ``url`` keyword argument;
+    2.  read the netrc file located at :file:`~/.netrc`, or at the path
+        stored in the :envvar:`$NETRC` environment variable, and look
+        for a username and password matching the hostname given in the
+        ``url`` keyword argument;
 
-    5.  if none of the above yield a credential, and ``fail_if_noauth=True``
-        was provided, raise a `ValueError`.
+5.  if none of the above yield a credential, and ``fail_if_noauth=True``
+    was provided, raise a `ValueError`.
 
-    Steps 2 and 3 are all tried independently, with all valid credentials
-    (one per type) configured for the session.
-    Only when SciTokens are disabled (``token=False``), will step 4 will be
-    tried to configure basic username/password auth.
-    It is up to the request receiver to handle the multiple credential
-    types and prioritise between them.
+Steps 2 and 3 are all tried independently, with all valid credentials
+(one per type) configured for the session.
+Only when SciTokens are disabled (``token=False``), will step 4 will be
+tried to configure basic username/password auth.
+It is up to the request receiver to handle the multiple credential
+types and prioritise between them.
 
-    Parameters
-    ----------
-    token : `scitokens.SciToken`, `str`, `bool`, optional
-        Bearer token (scitoken) input, one of
+Parameters
+----------
+token : `scitokens.SciToken`, `str`, `bool`, optional
+    Bearer token (scitoken) input, one of
 
-        - a bearer token (`scitokens.SciToken`),
-        - a serialised token (`str`, `bytes`),
-        - `False`: disable using tokens completely
-        - `True`: discover a valid token via
-          :func:`igwn_auth_utils.find_scitoken` and
-          error if something goes wrong
-        - `None`: try and discover a valid token, but
-          try something else if that fails
+    - a bearer token (`scitokens.SciToken`),
+    - a serialised token (`str`, `bytes`),
+    - `False`: disable using tokens completely
+    - `True`: discover a valid token via
+      :func:`igwn_auth_utils.find_scitoken` and
+      error if something goes wrong
+    - `None`: try and discover a valid token, but
+      try something else if that fails
 
-    token_audience : `str`, list` of `str`
-        The value(s) of the audience (``aud``) claim to pass to
-        :func:`igwn_auth_utils.find_scitoken` when discovering
-        available tokens.
+token_audience : `str`, list` of `str`
+    The value(s) of the audience (``aud``) claim to pass to
+    :func:`igwn_auth_utils.find_scitoken` when discovering
+    available tokens.
 
-    token_scope : `str`
-        The value(s) of the ``scope`` to pass to
-        :func:`igwn_auth_utils.find_scitoken` when discovering
-        available tokens.
+token_scope : `str`
+    The value(s) of the ``scope`` to pass to
+    :func:`igwn_auth_utils.find_scitoken` when discovering
+    available tokens.
 
-    token_issuer : `str`
-        The value of the issuer (``iss``) claim to pass to
-        :func:`igwn_auth_utils.find_scitoken` when discovering
-        available tokens.
+token_issuer : `str`
+    The value of the issuer (``iss``) claim to pass to
+    :func:`igwn_auth_utils.find_scitoken` when discovering
+    available tokens.
 
-    cert : `str`, `tuple`, `bool`, optional
-        X.509 credential input, one of
+cert : `str`, `tuple`, `bool`, optional
+    X.509 credential input, one of
 
-        - path to a PEM-format certificate file,
-        - a ``(cert, key)`` `tuple`,
-        - `False`: disable using X.509 completely
-        - `True`: discover a valid cert via
-          :func:`igwn_auth_utils.find_x509_credentials` and
-          error if something goes wrong
-        - `None`: try and discover a valid cert, but
-          try something else if that fails
+    - path to a PEM-format certificate file,
+    - a ``(cert, key)`` `tuple`,
+    - `False`: disable using X.509 completely
+    - `True`: discover a valid cert via
+      :func:`igwn_auth_utils.find_x509_credentials` and
+      error if something goes wrong
+    - `None`: try and discover a valid cert, but
+      try something else if that fails
 
-    auth :  `tuple`, `object`, optional
-        ``(username, password)`` `tuple` or other authentication/authorization
-        object to attach to a `~requests.Request`.
-        By default a new :class:`HTTPSciTokenAuth` handler will be attached
-        to configure ``Authorization`` headers for each request.
+auth :  `tuple`, `object`, optional
+    ``(username, password)`` `tuple` or other authentication/authorization
+    object to attach to a `~requests.Request`.
+    By default a new :class:`HTTPSciTokenAuth` handler will be attached
+    to configure ``Authorization`` headers for each request.
 
-    url : `str`, optional
-        the URL/host that will be queried within this session; this is used
-        to set the default ``token_audience`` and to access credentials
-        via :mod:`safe_netrc`.
+url : `str`, optional
+    the URL/host that will be queried within this session; this is used
+    to set the default ``token_audience`` and to access credentials
+    via :mod:`safe_netrc`.
 
-    force_noauth : `bool`, optional
-        Disable the use of any authorisation credentials (mainly for testing).
+force_noauth : `bool`, optional
+    Disable the use of any authorisation credentials (mainly for testing).
 
-    fail_if_noauth : `bool`, optional
-        Raise a `~igwn_auth_utils.IgwnAuthError` if no authorisation
-        credentials are presented or discovered.
+fail_if_noauth : `bool`, optional
+    Raise a `~igwn_auth_utils.IgwnAuthError` if no authorisation
+    credentials are presented or discovered.
 
-    raise_for_status : `bool`, optional
-        If `True` (default), automatically call
-        :meth:`~requests.Response.raise_for_status` after receiving
-        any response.
+raise_for_status : `bool`, optional
+    If `True` (default), automatically call
+    :meth:`~requests.Response.raise_for_status` after receiving
+    any response.
 
-    Raises
-    ------
-    ~igwn_auth_utils.IgwnAuthError
-        If ``cert=True`` or ``token=True`` is given and the relevant
-        credential was not actually discovered, or
-        if ``fail_if_noauth=True`` is given and no authorisation
-        token/credentials of any valid type are presented or discovered.
+Raises
+------
+~igwn_auth_utils.IgwnAuthError
+    If ``cert=True`` or ``token=True`` is given and the relevant
+    credential was not actually discovered, or
+    if ``fail_if_noauth=True`` is given and no authorisation
+    token/credentials of any valid type are presented or discovered.
 
-    See also
-    --------
-    requests.Session
-        for details of the standard options
+See also
+--------
+requests.Session
+    for details of the standard options
 
-    igwn_auth_utils.find_scitoken
-        for details of the SciToken discovery
+igwn_auth_utils.find_scitoken
+    for details of the SciToken discovery
 
-    igwn_auth_utils.find_x509_credentials
-        for details of the X.509 credential discovery
-    """.strip()
+igwn_auth_utils.find_x509_credentials
+    for details of the X.509 credential discovery
+""".strip()
+if sys.version_info < (3, 13, 0):
+    # older versions don't have https://github.com/python/cpython/issues/81283
+    _auth_session_parameters = indent(_auth_session_parameters, "    ").strip()
 
 
 def _hook_raise_for_status(response, *args, **kwargs):
-    """Response hook to raise exception for any HTTP error (status >= 400)
+    """Response hook to raise exception for any HTTP error (status >= 400).
 
     Reproduced (with permission) from :mod:`requests_gracedb.errors`,
     authored by Leo Singer.
@@ -389,12 +378,12 @@ def _hook_raise_for_status(response, *args, **kwargs):
 
 
 class SessionErrorMixin:
-    """A mixin for :class:`requests.Session` to raise exceptions for HTTP
-    errors.
+    """`requests.Session` mixin to raise exceptions for HTTP errors.
 
     Reproduced (with permission) from :mod:`requests_gracedb.errors`,
     authored by Leo Singer.
     """
+
     def __init__(self, *args, **kwargs):
         raise_for_status = kwargs.pop("raise_for_status", True)
         super().__init__(*args, **kwargs)
@@ -413,6 +402,7 @@ class SessionAuthMixin:
 
     {parameters}
     """
+
     def __init__(
         self,
         token=None,
@@ -443,8 +433,7 @@ class SessionAuthMixin:
         )
 
     def _init_auth(self, url=None, token=None, **kwargs):
-        """Initialise the auth handler for this `Session`.
-        """
+        """Initialise the auth handler for this `Session`."""
         # find creds if we can
         self.auth, self.cert = _prepare_auth(url=url, token=token, **kwargs)
 
@@ -503,6 +492,7 @@ class Session(
     >>> with Session(force_noauth=True) as sess:
     ...     sess.get("https://science.example.com/api/important/data")
     """
+
     __attrs__ = requests.Session.__attrs__ = [
         "token",
     ]
@@ -579,7 +569,7 @@ def request(method, url, *args, session=None, **kwargs):
     resp : `requests.Response`
         the response object
 
-    See also
+    See Also
     --------
     igwn_auth_utils.requests.Session.request
         for information on how the request is performed
@@ -608,37 +598,38 @@ def request(method, url, *args, session=None, **kwargs):
 
 
 _request_wrapper_doc = """
-    Send an HTTP {METHOD} request to the specified URL with IGWN Auth attached.
+Send an HTTP {METHOD} request to the specified URL with IGWN Auth attached.
 
-    Parameters
-    ----------
-    url : `str`
-        The URL to request.
+Parameters
+----------
+url : `str`
+    The URL to request.
 
-    session : `requests.Session`, optional
-        The connection session to use, if not given one will be
-        created on-the-fly.
+session : `requests.Session`, optional
+    The connection session to use, if not given one will be
+    created on-the-fly.
 
-    args, kwargs
-        All other keyword arguments are passed directly to
-        :meth:`requests.Session.{method}`
+args, kwargs
+    All other keyword arguments are passed directly to
+    :meth:`requests.Session.{method}`
 
-    Returns
-    -------
-    resp : `requests.Response`
-        the response object
+Returns
+-------
+resp : `requests.Response`
+    the response object
 
-    See also
-    --------
-    requests.Session.{method}
-        for information on how the request is performed
+See Also
+--------
+requests.Session.{method}
+    for information on how the request is performed
 """.strip()
+if sys.version_info < (3, 13, 0):
+    # older versions don't have https://github.com/python/cpython/issues/81283
+    _request_wrapper_doc = indent(_request_wrapper_doc, "    ").strip()
 
 
 def _request_wrapper_factory(method):
-    """Factor function to wrap a :mod:`requests` HTTP method to use
-    our request function.
-    """
+    """Return a wrapper around ``method`` that uses our `request` function."""
     def _request_wrapper(url, *args, session=None, **kwargs):
         return request(method, url, *args, session=session, **kwargs)
 
