@@ -1,9 +1,7 @@
-# -*- coding: utf-8 -*-
-# Copyright 2021-2022 Cardiff University
+# Copyright (c) 2021-2025 Cardiff University
 # Distributed under the terms of the BSD-3-Clause license
 
-"""Tests for :mod:`igwn_auth_utils.requests`.
-"""
+"""Tests for :mod:`igwn_auth_utils.requests`."""
 
 __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
 __credits__ = "Leo Singer <leo.singer@ligo.org>"
@@ -11,6 +9,7 @@ __credits__ = "Leo Singer <leo.singer@ligo.org>"
 import os
 import stat
 from netrc import NetrcParseError
+from pathlib import Path
 from unittest import mock
 from urllib.parse import urlencode
 
@@ -31,6 +30,11 @@ SKIP_REQUESTS_NETRC = pytest.mark.skipif(
     reason=f"requests {requests_version} doesn't respect NETRC env",
 )
 
+x509_warning_ctx = pytest.warns(
+    DeprecationWarning,
+    match="Support for identity-based X.509 credentials",
+)
+
 
 # -- utilities ------------------------
 
@@ -51,8 +55,8 @@ def mock_no_scitoken():
 
 def mock_no_x509():
     return mock.patch(
-        "igwn_auth_utils.requests.find_x509_credentials",
-        _igwnerror,
+        "igwn_auth_utils.x509._find_credentials",
+        _empty,
     )
 
 
@@ -117,7 +121,10 @@ def test_get_netrc_auth_notfound(tmp_path):
 def test_get_netrc_auth_permissions(netrc):
     os.environ["NETRC"] = str(netrc)
     netrc.chmod(0o444)
-    with pytest.raises(NetrcParseError):
+    with pytest.raises(
+        NetrcParseError,
+        match="too permissive",
+    ):
         igwn_requests.get_netrc_auth(None, raise_errors=True)
     assert igwn_requests.get_netrc_auth(None, raise_errors=False) is None
 
@@ -146,8 +153,7 @@ class TestHTTPSciTokenAuth:
 
     @mock.patch("igwn_auth_utils.requests.find_scitoken")
     def test_token_header_empty(self, find_token):  # noqa: F811
-        """Test that the auth class handles no tokens properly.
-        """
+        """Test that the auth class handles no tokens properly."""
         find_token.return_value = None
         req = MockRequest()
         auth = self.Auth()
@@ -155,9 +161,7 @@ class TestHTTPSciTokenAuth:
 
     @mock.patch("igwn_auth_utils.requests.find_scitoken")
     def test_token_header(self, find_token, rtoken):  # noqa: F811
-        """Test that the auth class finds the token and serialises
-        it into a header properly.
-        """
+        """Test token header serialization."""
         find_token.return_value = rtoken
 
         auth = self.Auth()
@@ -187,21 +191,24 @@ class TestSession:
             RequestException,
             match=r"404 Client Error: not found for url: https://test.org/",
         ):
-            igwn_requests.get("https://test.org")
+            igwn_requests.get("https://test.org", cert=False)
 
     # -- session auth
 
     def test_noauth_args(self):
-        """Test that `Session(force_noauth=True, fail_if_noauth=True)`
-        is invalid.
-        """
-        with pytest.raises(ValueError):
+        """Test that `Session(force_noauth=True, fail_if_noauth=True)` is invalid."""
+        with pytest.raises(
+            ValueError,
+            match="cannot select both force_noauth and fail_if_noauth",
+        ):
             self.Session(force_noauth=True, fail_if_noauth=True)
 
     def test_fail_if_noauth(self):
-        """Test that `Session(fail_if_noauth=True)` raises an error
-        """
-        with pytest.raises(IgwnAuthError):
+        """Test that `Session(fail_if_noauth=True)` raises an error."""
+        with pytest.raises(
+            IgwnAuthError,
+            match="no valid authorisation credentials found",
+        ):
             self.Session(
                 token=False,
                 cert=False,
@@ -210,8 +217,7 @@ class TestSession:
             )
 
     def test_force_noauth(self):
-        """Test that `Session(force_noauth=True)` overrides auth kwargs
-        """
+        """Test that `Session(force_noauth=True)` overrides auth kwargs."""
         sess = self.Session(cert="cert.pem", force_noauth=True)
         assert sess.cert is False
         assert sess.auth is None
@@ -219,9 +225,9 @@ class TestSession:
     @mock_no_scitoken()
     @mock_no_x509()
     def test_defaults(self):
-        """Test that the `Session()` defaults work in a noauth environment
-        """
-        sess = self.Session()
+        """Test that the `Session()` defaults work in a noauth environment."""
+        with x509_warning_ctx:
+            sess = self.Session()
         assert sess.cert is None
         assert isinstance(sess.auth, igwn_requests.HTTPSciTokenAuth)
         assert sess.auth.token is None
@@ -229,9 +235,8 @@ class TestSession:
     # -- tokens
 
     def test_token_explicit(self, rtoken):  # noqa: F811
-        """Test that tokens are handled properly
-        """
-        sess = self.Session(token=rtoken)
+        """Test that tokens are handled properly."""
+        sess = self.Session(token=rtoken, cert=False)
         assert sess.auth.token is rtoken
         # mock the request to get the header that would be used
         req = MockRequest()
@@ -241,10 +246,9 @@ class TestSession:
         )
 
     def test_token_serialized(self, rtoken):  # noqa: F811
-        """Test that serialized tokens are handled properly
-        """
+        """Test that serialized tokens are handled properly."""
         serialized = rtoken.serialize()
-        sess = self.Session(token=serialized)
+        sess = self.Session(token=serialized, cert=False)
         req = MockRequest()
         sess.auth(req)
         assert req.headers["Authorization"] == f"Bearer {serialized}"
@@ -254,7 +258,7 @@ class TestSession:
     @mock.patch("igwn_auth_utils.requests.find_scitoken")
     def test_token_discovery(self, find_token, rtoken):  # noqa: F811
         find_token.return_value = rtoken
-        sess = self.Session()
+        sess = self.Session(cert=False)
         sess.auth(sess)
         assert sess.headers["Authorization"] == (
             igwn_requests.scitoken_authorization_header(rtoken)
@@ -262,11 +266,17 @@ class TestSession:
 
     @mock.patch(
         "igwn_auth_utils.requests.find_scitoken",
-        side_effect=IgwnAuthError,
+        side_effect=IgwnAuthError("mock error"),
     )
     def test_token_required_failure(self, _):
-        with pytest.raises(IgwnAuthError), self.Session(token=True) as sess:
-            sess.get("https://example.com")
+        errctx = pytest.raises(
+            IgwnAuthError,
+            match="mock error",
+        )
+        with x509_warning_ctx:
+            sess = self.Session(token=True)
+            with errctx, sess:
+                sess.get("https://example.com")
 
     @pytest.mark.parametrize(("url", "aud"), (
         ("https://secret.example.com:8008", ["https://secret.example.com"]),
@@ -274,8 +284,7 @@ class TestSession:
     ))
     @mock.patch("igwn_auth_utils.requests.find_scitoken")
     def test_token_audience_default(self, find_scitoken, url, aud):
-        """Check that the default `token_audience` is set correctly.
-        """
+        """Check that the default `token_audience` is set correctly."""
         sess = self.Session(
             url=url,
             token=True,
@@ -287,8 +296,7 @@ class TestSession:
     # -- X.509
 
     def test_cert_explicit(self):
-        """Test that cert credentials are stored properly
-        """
+        """Test that cert credentials are stored properly."""
         sess = self.Session(token=False, cert="cert.pem")
         assert sess.cert == "cert.pem"
         assert sess.auth is None
@@ -298,26 +306,18 @@ class TestSession:
         return_value="test.pem",
     )
     def test_cert_discovery(self, _):
-        """Test that automatic certificate discovery works
-        """
+        """Test that automatic certificate discovery works."""
         assert self.Session(token=False).cert == "test.pem"
 
-    @pytest.mark.skipif(
-        not igwn_requests.REQUESTS_CERT_HTTP_BUG,
-        reason=f"bug not present on requests {requests_version}",
-    )
-    def test_cert_requests_214(self):
-        """Test that cert is disabled on requests 2.14 by default.
-        """
-        s = self.Session(url="http://example.com")
-        assert s.cert is False
-
     @mock.patch(
         "igwn_auth_utils.requests.find_x509_credentials",
-        side_effect=IgwnAuthError,
+        side_effect=IgwnAuthError("mock error"),
     )
     def test_cert_required_failure(self, _):
-        with pytest.raises(IgwnAuthError):
+        with pytest.raises(
+            IgwnAuthError,
+            match="mock error",
+        ):
             self.Session(token=False, cert=True)
 
     # -- basic auth
@@ -356,7 +356,7 @@ class TestSession:
         token,
         auth,
     ):
-        """Check that Session._init_auth records all auth options
+        """Check that Session._init_auth records all auth options.
 
         In case a remote host accepts X.509 but not tokens, but the user
         has a valid ANY token (for example).
@@ -373,17 +373,34 @@ class TestSession:
     # -- request auth
     # test that Session auth and Request auth play nicely together
 
+    @mock.patch.dict("os.environ")
     @mock.patch(
-        "igwn_auth_utils.x509.is_valid_certificate",
-        return_value=False,
+        "igwn_auth_utils.x509._default_cert_path",
+        return_value=Path("does-not-exist"),
     )
-    def test_request_x509(self, is_valid, requests_mock, tmp_path):
-        """Test that a request does its own search for an X.509 cert.
-        """
+    @mock.patch(
+        "igwn_auth_utils.x509._globus_cert_path",
+        return_value=(Path("does-not-exist"), Path("does-not-exist")),
+    )
+    @mock.patch(
+        "igwn_auth_utils.x509.validate_certificate",
+        return_value=True,
+    )
+    def test_request_x509(
+        self,
+        # mocks
+        validate,
+        _globus,
+        _cert,
+        # fixtures
+        requests_mock,
+        tmp_path,
+    ):
+        """Test that a request does its own search for an X.509 cert."""
         x509 = tmp_path / "x509"
         requests_mock.get("https://example.com")
-        with mock.patch.dict(os.environ):
-            os.environ.pop("X509_USER_PROXY", None)
+        os.environ.pop("X509_USER_PROXY", None)
+        with x509_warning_ctx:
             with self.Session(cert=None) as sess:
                 # check that the Session doesn't have a cert
                 assert sess.cert is None
@@ -414,8 +431,7 @@ class TestSession:
         request_aud,
         request_scope,
     ):
-        """Test that a request correctly merges token claim settings.
-        """
+        """Test that a request correctly merges token claim settings."""
         requests_mock.get("https://example.com/api")
         with self.Session(
             cert=False,
@@ -449,15 +465,17 @@ class TestSession:
 
     @mock.patch("igwn_auth_utils.requests.find_scitoken", return_value=None)
     def test_request_fail_if_noauth(self, find_scitoken):
-        """Test that `Session.get(fail_if_noauth=True)` raises an error.
-        """
-        with self.Session(fail_if_noauth=False) as sess, \
-             pytest.raises(IgwnAuthError, match="no valid authorisation"):
-            sess.get(
-                "https://example.com",
-                cert=False,
-                fail_if_noauth=True,
-            )
+        """Test that `Session.get(fail_if_noauth=True)` raises an error."""
+        with x509_warning_ctx:
+            with self.Session(fail_if_noauth=False) as sess, pytest.raises(
+                IgwnAuthError,
+                match="no valid authorisation",
+            ):
+                sess.get(
+                 "https://example.com",
+                 cert=False,
+                 fail_if_noauth=True,
+             )
 
     @mock.patch("igwn_auth_utils.requests.HTTPSciTokenAuth.__call__")
     def test_request_token_false(self, token_auth_call, requests_mock):
@@ -481,32 +499,32 @@ class TestSession:
 # -- standalone requests --------------
 
 def test_get(requests_mock):
-    """Test that `igwn_auth_utils.requests.get` can perform a simple request
-    """
+    """Test that `igwn_auth_utils.requests.get` can perform a simple request."""
     requests_mock.get(
         "https://test.org",
         text="TEST",
     )
-    assert igwn_requests.get("https://test.org").text == "TEST"
+    assert igwn_requests.get(
+        "https://test.org",
+        cert=False,
+    ).text == "TEST"
 
 
 @mock.patch("igwn_auth_utils.requests.HTTPSciTokenAuth.__call__")
 def test_get_token_false(token_auth_call, requests_mock):
-    """Test that `igwn_auth_utils.requests.get` respects token=False.
-    """
+    """Test that `igwn_auth_utils.requests.get` respects token=False."""
     requests_mock.get(
         "https://test.org",
         text="TEST",
     )
-    igwn_requests.get("https://test.org", token=False)
+    igwn_requests.get("https://test.org", token=False, cert=False)
     # assert that HTTPSciTokenAuth is never actually invoked
     token_auth_call.assert_not_called()
 
 
 @mock.patch("igwn_auth_utils.requests.Session")
 def test_get_session(mock_session):
-    """Test that ``session`` for `igwn_auth_utils.requests.get` works
-    """
+    """Test that ``session`` for `igwn_auth_utils.requests.get` works."""
     session = mock.MagicMock()
     assert igwn_requests.get("https://test.org", session=session)
     session.request.assert_called_once_with("get", "https://test.org")
@@ -527,8 +545,7 @@ def test_get_force_noauth(find_x509, find_scitoken, requests_mock):
 
 
 def test_post(requests_mock):
-    """Test that `igwn_auth_utils.requests.post` can perform a simple request.
-    """
+    """Test that `igwn_auth_utils.requests.post` can perform a simple request."""
     data = {"a": 1, "b": 2}
     requests_mock.post(
         "https://example.com",
@@ -538,6 +555,7 @@ def test_post(requests_mock):
     assert igwn_requests.post(
         "https://example.com",
         data=data,
+        cert=False,
     ).text == "THANKS"
     # check that the data was encoded into the request properly
     req = requests_mock.request_history[0]
